# 2025.03.0

**Released on March 28th, 2025**

[Documentation for this release](https://cotainr.readthedocs.org/en/2025.03.0/)

A major release focused on updating project packaging and tooling, as well as adding ARM support.

## New features

- Cotainr is now available through pip and all documentation has been changed to reflect this. Additionally, the publishing has been automated through GitHub actions, [PR#117](https://github.com/DeiC-HPC/cotainr/pull/117) [PR#118](https://github.com/DeiC-HPC/cotainr/pull/118) [PR#120](https://github.com/DeiC-HPC/cotainr/pull/120) [PR#127](https://github.com/DeiC-HPC/cotainr/pull/127).
- ARM is now officially supported on a smaller test matrix that includes Apptainer but excludes Singularity-CE and Singularity, [PR#115](https://github.com/DeiC-HPC/cotainr/pull/115).

## Bug fixes

- Ensure files are created in the context of the container to get correct file permissions, [PR#80](https://github.com/DeiC-HPC/cotainr/pull/80) [PR#79](https://github.com/DeiC-HPC/cotainr/pull/79).

## Maintenance updates

- The Python packaging now follows the pyproject.toml standard, as well as implementing the dependency-groups of PEP735, [PR#107](https://github.com/DeiC-HPC/cotainr/pull/107), [PR#57](https://github.com/DeiC-HPC/cotainr/pull/57), [PR#65](https://github.com/DeiC-HPC/cotainr/pull/65), [PR#126](https://github.com/DeiC-HPC/cotainr/pull/126) [PR#112](https://github.com/DeiC-HPC/cotainr/pull/112) [PR#113](https://github.com/DeiC-HPC/cotainr/pull/113).
- Deprecate Python 3.8, [PR#119](https://github.com/DeiC-HPC/cotainr/pull/119)
- The project has been updated to primarily use the `uv` tool for dependency resolution, installation and publishing.
